==> cards-0.2.9.tar.gz: cards-0.2.9/docs/contributing.md <==
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

You can contribute in many ways:

Types of Contributions
----------------------

### Report Bugs

Report bugs at <https://github.com/okken/cards/issues>.

If you are reporting a bug, please include:

-   Your operating system name and version.
-   Any details about your local setup that might be helpful in
    troubleshooting.
-   Detailed steps to reproduce the bug.

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug" and
"help wanted" is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features. Anything tagged with
"enhancement" and "help wanted" is open to whoever wants to implement
it.

### Write Documentation

cards could always use more documentation, whether as part of the
official cards docs, in docstrings, or even on the web in blog posts,
articles, and such.


### Submit Feedback

The best way to send feedback is to file an issue at
<https://github.com/okken/cards/issues>.

If you are proposing a feature:

-   Explain in detail how it would work.
-   Keep the scope as narrow as possible, to make it easier to
    implement.
-   Remember that this is a volunteer-driven project, and that
    contributions are welcome :)

Get Started!
------------

Ready to contribute? Here's how to set up cards for local development.

1.  Fork the cards repo on GitHub.
2.  Clone your fork locally:

        $ git clone git@github.com:your_name_here/cards.git

3.  Install your local copy into a virtual environment:

        $ cd cards/
        $ python3.6 -m venv venv --prompt cards
        $ source venv/bin/activate
        $ pip install -e .
        $ pip install -r requirements_dev.txt

4.  Create a branch for local development:

        $ git checkout -b name-of-your-bugfix-or-feature

    Now you can make your changes locally.

5.  When you're done making changes, check that your changes pass flake8
    and the tests, including testing other Python versions with tox:

        $ flake8 cards tests
        $ pytest
        $ tox

    To get flake8 and tox, just pip install them into your virtualenv.

6.  Commit your changes and push your branch to GitHub:

        $ git add .
        $ git commit -m "Your detailed description of your changes."
        $ git push origin name-of-your-bugfix-or-feature

7.  Submit a pull request through the GitHub website.

Pull Request Guidelines
-----------------------

Before you submit a pull request, check that it meets these guidelines:

1.  The pull request should include tests.
2.  If the pull request adds functionality, the docs should be updated.
    Put your new functionality into a function with a docstring, and add
    the feature to the list in README.rst.
3.  The pull request should work for Python 3.6. Check <https://travis-ci.org/okken/cards/pull_requests>
    and make sure that the tests pass for all supported Python versions.

Tips
----

To run a subset of tests:

    pytest tests.test_cards.py

Deploying
---------

A reminder for the maintainers on how to deploy. Make sure all your
changes are committed (including an entry in docs/history.md).

Update versions in setup.py and cards/\_\_init\_\_.py.

Then run:

    $ git push
    $ git push --tags

Travis will then deploy to PyPI if tests pass. (really?)

==> cards-1.0.1.tar.gz: cards-1.0.1/docs/contributing.md <==
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

You can contribute in many ways:

Types of Contributions
----------------------

### Report Bugs

Report bugs at <https://github.com/okken/cards/issues>.

If you are reporting a bug, please include:

-   Your operating system name and version.
-   Any details about your local setup that might be helpful in
    troubleshooting.
-   Detailed steps to reproduce the bug.

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug" and
"help wanted" is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features. Anything tagged with
"enhancement" and "help wanted" is open to whoever wants to implement
it.

### Write Documentation

cards could always use more documentation, whether as part of the
official cards docs, in docstrings, or even on the web in blog posts,
articles, and such.


### Submit Feedback

The best way to send feedback is to file an issue at
<https://github.com/okken/cards/issues>.

If you are proposing a feature:

-   Explain in detail how it would work.
-   Keep the scope as narrow as possible, to make it easier to
    implement.
-   Remember that this is a volunteer-driven project, and that
    contributions are welcome :)

Get Started!
------------

Ready to contribute? Here's how to set up cards for local development.

1.  Fork the cards repo on GitHub.
2.  Clone your fork locally:

    ```console
    $ git clone git@github.com:your_name_here/cards.git
    ```

3.  Install your local copy into a virtual environment:

    ```console
    $ cd cards/
    $ python3.6 -m venv venv --prompt cards
    $ source venv/bin/activate
    $ pip install flit
    $ flit install --pth-file
    $ pip install -r requirements-dev.txt
    ```

4.  Create a branch for local development:

    ```console
    $ git checkout -b name-of-your-bugfix-or-feature
    ```

    Now you can make your changes locally.

5.  When you're done making changes, check that your changes pass flake8
    and the tests, including testing other Python versions with tox:

    ```console
    $ flake8 cards tests
    $ pytest
    $ tox
    ```

    To get flake8 and tox, just pip install them into your virtualenv.

6.  Commit your changes and push your branch to GitHub:

    ```console
    $ git add .
    $ git commit -m "Your detailed description of your changes."
    $ git push origin name-of-your-bugfix-or-feature
    ```

7.  Submit a pull request through the GitHub website.

Pull Request Guidelines
-----------------------

Before you submit a pull request, check that it meets these guidelines:

1.  The pull request should include tests.
2.  If the pull request adds functionality, the docs should be updated.
    Put your new functionality into a function with a docstring, and add
    the feature to the list in README.rst.
3.  The pull request should work for Python 3.6. Check <https://travis-ci.org/okken/cards/pull_requests>
    and make sure that the tests pass for all supported Python versions.

Tips
----

To run a subset of tests:

    pytest tests.test_cards.py

Deploying
---------

A reminder for the maintainers on how to deploy. Make sure all your
changes are committed (including an entry in docs/history.md).

Update versions in setup.py and cards/\_\_init\_\_.py.

Then run:

    ```console
    $ git push
    $ git push --tags
    ```

Travis will then deploy to PyPI if tests pass. (really?)
